# `royalpack` [![PyPI](https://img.shields.io/pypi/v/royalpack.svg)](https://pypi.org/project/royalpack/)

The Royalnet Pack used in the Royal Games community!

## Commands

### `ciaoruozi`

### `color`

### `cv`

### `diario`

### `rage`

### `reminder`

### `ship`

### `smecds`

### `videochannel`

### `trivia`

### `matchmaking`

### `pause`

### `play`

### `playmode`

### `queue`

### `skip`

### `summon`

### `youtube`

### `soundcloud`

### `zawarudo`

### `emojify`

### `leagueoflegends`

### `diarioquote`

### `mp3`

### `peertube`

## Stars

### `/api/diario/list`

### `/api/diario/get/{id}`

### `/api/user/list`

### `/api/user/get/{id}`
